changeset 4553:1a714d3f0233 libavcodec

cosmetics: Fix a common typo, sepErate --> sepArate.
author diego
date Wed, 21 Feb 2007 10:15:08 +0000
parents c31d78661cf2
children 384e4c438534
files h264.c oggvorbis.c
diffstat 2 files changed, 6 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/oggvorbis.c	Tue Feb 20 12:45:16 2007 +0000
+++ b/oggvorbis.c	Wed Feb 21 10:15:08 2007 +0000
@@ -159,7 +159,9 @@
         vorbis_bitrate_addblock(&context->vb) ;
 
         while(vorbis_bitrate_flushpacket(&context->vd, &op)) {
-            if(op.bytes==1) //id love to say this is a hack, bad sadly its not, appearently the end of stream decission is in libogg
+            /* i'd love to say the following line is a hack, but sadly it's
+             * not, apparently the end of stream decision is in libogg. */
+            if(op.bytes==1)
                 continue;
             memcpy(context->buffer + context->buffer_index, &op, sizeof(ogg_packet));
             context->buffer_index += sizeof(ogg_packet);
--- a/h264.c	Tue Feb 20 12:45:16 2007 +0000
+++ b/h264.c	Wed Feb 21 10:15:08 2007 +0000
@@ -1952,8 +1952,8 @@
 }
 
 //FIXME need to check that this doesnt overflow signed 32 bit for low qp, i am not sure, it's very close
-//FIXME check that gcc inlines this (and optimizes intra & seperate_dc stuff away)
-static inline int quantize_c(DCTELEM *block, uint8_t *scantable, int qscale, int intra, int seperate_dc){
+//FIXME check that gcc inlines this (and optimizes intra & separate_dc stuff away)
+static inline int quantize_c(DCTELEM *block, uint8_t *scantable, int qscale, int intra, int separate_dc){
     int i;
     const int * const quant_table= quant_coeff[qscale];
     const int bias= intra ? (1<<QUANT_SHIFT)/3 : (1<<QUANT_SHIFT)/6;
@@ -1961,7 +1961,7 @@
     const unsigned int threshold2= (threshold1<<1);
     int last_non_zero;
 
-    if(seperate_dc){
+    if(separate_dc){
         if(qscale<=18){
             //avoid overflows
             const int dc_bias= intra ? (1<<(QUANT_SHIFT-2))/3 : (1<<(QUANT_SHIFT-2))/6;